@@ -261,6 +261,16 @@ class MainWindow(QtWidgets.QMainWindow):
         # Should this be a signal? Like Startup done, now you can refresh?
         self.splash_screen.finish(self)
         self.in_startup = False
+        t = QtCore.QTimer()
+        t.setInterval(256)
+
+        def failure_check():
+            if self.view:
+                self.view.failure_check()
+            t.stop()
+        t.timeout.connect(failure_check)
+        t.start()
+
         app = QtWidgets.QApplication.instance()
         app.aboutToQuit.connect(self.shutdown_rpc_server)
 
@@ -1075,8 +1085,11 @@ class MenuBar(QtWidgets.QMenuBar):
         self.view_menu.addSeparator()
         self.view_menu.addAction(self.view_actions.implicit_action)
         self.view_menu.addAction(self.view_actions.grid_action)
-        self.view_menu.addAction(self.view_actions.tooltip_action)
-        self.view_menu.addAction(self.layer_actions.lay_manger_table_action)
+        self.view_opt_menu = self.view_menu.addMenu('Options')
+        self.view_opt_menu.setTearOffEnabled(True)
+        self.view_opt_menu.addAction(self.view_actions.tooltip_action)
+        self.view_opt_menu.addAction(self.layer_actions.lay_manger_table_action)
+        self.view_opt_menu.addAction(self.ce_actions.overlay_message_action)
 
         # graph menu
         self.graph_menu = self.addMenu('Graph')
